@@ -1,10 +1,14 @@
+import logging
+
 from seleniumtabs.browser_management import browser_sessions
 from seleniumtabs.exceptions import SeleniumRequestException
-from seleniumtabs.schedule_tasks import task_scheduler
+from seleniumtabs.schedule_tasks import BrowserTaskScheduler, task_scheduler
 from seleniumtabs.session import Session
 from seleniumtabs.tabs import Tab, TabManager
 from seleniumtabs.wait import humanized_wait
 
+logger = logging.getLogger(__name__)
+
 
 class Browser:
     """
@@ -21,19 +25,24 @@ class Browser:
         headless: bool = False,
         full_screen: bool = True,
     ):
+        logger.info(f"Initializing Browser with name: {name}")
         self.name = name
 
+        logger.info("Creating new Session")
         self._session = Session(
             name,
             headless=headless,
             implicit_wait=implicit_wait,
             user_agent=user_agent,
+            full_screen=full_screen,
         )
-        self._manager: TabManager = TabManager(self._session)
+        logger.info("Session created successfully")
 
+        self._manager: TabManager = TabManager(self._session)
         self.full_screen = full_screen
 
         browser_sessions.add_browser(self)
+        logger.info("Browser initialization complete")
 
     def __enter__(self) -> "Browser":
         """Context manager entry point"""
@@ -43,6 +52,10 @@ class Browser:
         """Context manager exit point - ensures browser is closed"""
         self.close()
 
+    def __del__(self) -> None:
+        """Destructor to ensure browser cleanup when object is garbage collected"""
+        self.close()
+
     @property
     def tabs(self) -> list[Tab]:
         """Returns all open tabs in the browser"""
@@ -99,6 +112,9 @@ class Browser:
             SeleniumRequestException: If the tab does not exist
         """
         if self._manager.exist(tab):
+            # Cancel any tasks scheduled for this tab
+            task_scheduler.cancel_tab_tasks(tab)
+
             tab.switch()
             self._remove_tab(tab=tab)
             humanized_wait(1)
@@ -107,11 +123,41 @@ class Browser:
 
         raise SeleniumRequestException("Tab does not exist.")
 
+    def close_all_tabs(self) -> None:
+        """Close all tabs while keeping the browser instance alive.
+
+        This method:
+        1. Cancels any scheduled tasks
+        2. Closes all tabs in reverse order (to avoid issues with tab handles)
+        3. Clears the tab manager
+        4. Keeps the browser session active
+        """
+        # Cancel any scheduled tasks first
+        task_scheduler.cancel_all_tasks()
+
+        for tab in self.tabs:
+            tab.close()
+
     def close(self) -> None:
         """Close the browser and clean up all resources"""
-        humanized_wait(1)
-        self._manager.clear()
-        self._session.close()
+        try:
+            # Cancel any scheduled tasks first
+            task_scheduler.cancel_all_tasks()
+
+            # Close all tabs and clear the manager
+            if hasattr(self, "_manager"):
+                self._manager.clear()
+
+            # Close the session
+            if hasattr(self, "_session"):
+                self._session.close()
+
+            # Remove from browser sessions
+            if hasattr(self, "name"):
+                browser_sessions.browser_sessions = [b for b in browser_sessions.browser_sessions if b != self]
+
+        except Exception:
+            raise
 
     def __contains__(self, item: Tab) -> bool:
         """Check if a tab exists in the browser"""
@@ -142,10 +188,17 @@ class Browser:
         if self._manager and self._manager.last_tab:
             self._manager.last_tab.switch()
 
-    def execute_task(self, max_time: int | None = None) -> None:
+    @property
+    def task_scheduler(self) -> BrowserTaskScheduler:
+        return task_scheduler
+
+    def execute_task(self, max_time: int | None = None, sleep_time: float = 1.0) -> None:
         """Execute scheduled tasks.
 
         Args:
             max_time: Maximum time in seconds to execute tasks. If None, no time limit is applied.
+            sleep_time: Time in seconds to sleep between task checks. Defaults to 1.0 second.
+                      Lower values will check for tasks more frequently but use more CPU.
+                      Higher values will use less CPU but may delay task execution.
         """
-        task_scheduler.execute_tasks(max_time)
+        self.task_scheduler.execute_tasks(max_time=max_time, sleep_time=sleep_time)
